@@ -1,9 +1,8 @@
-import json
-
 from IPython.display import SVG, display
 import networkx as nx
 
 
+from python_workflow_definition.models import PythonWorkflowDefinitionWorkflow
 from python_workflow_definition.purepython import group_edges
 from python_workflow_definition.shared import (
     get_kwargs,
@@ -16,8 +15,7 @@ from python_workflow_definition.shared import (
 
 
 def plot(file_name: str):
-    with open(file_name, "r") as f:
-        content = json.load(f)
+    content = PythonWorkflowDefinitionWorkflow.load_json_file(file_name=file_name)
 
     graph = nx.DiGraph()
     node_dict = convert_nodes_list_to_dict(nodes_list=content[NODES_LABEL])
@@ -39,7 +37,10 @@ def plot(file_name: str):
                     k + "=result[" + v[SOURCE_PORT_LABEL] + "]"
                 )
         for k, v in edge_label_dict.items():
-            graph.add_edge(str(k), str(target_node), label=", ".join(v))
+            if len(v) == 1 and v[0] is not None:
+                graph.add_edge(str(k), str(target_node), label=", ".join(v))
+            else:
+                graph.add_edge(str(k), str(target_node))
 
     svg = nx.nx_agraph.to_agraph(graph).draw(prog="dot", format="svg")
     display(SVG(svg))
